package com.mosty.sjzx.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.mosty.base.model.query.sjzx.*;
import io.swagger.annotations.ApiOperation;

import java.util.List;
import java.util.Map;

public interface SgfxService {

    @ApiOperation("日统计-街面警情")
    List<Map<String, Object>> jmjq(YszxQuery dto);

    @ApiOperation("日统计-违法犯罪警情")
    List<Map<String, Object>> wffzjq(YszxQuery dto);

    @ApiOperation("日统计-总警情")
    List<Map<String, Object>> zjq(YszxQuery dto);

    @ApiOperation("月统计-街面警情")
    List<Map<String, Object>> yjmjq(YszxNyQuery dto);

    @ApiOperation("月统计-违法犯罪警情")
    List<Map<String, Object>> yzwffzjq(YszxNyQuery dto);

    @ApiOperation("月统计-总警情")
    List<Map<String, Object>> yzjq(YszxNyQuery dto);

    @ApiOperation("周统计-街面警情")
    List<Map<String, Object>> zjmjq(YszxQuery dto);

    @ApiOperation("周统计-违法犯罪警情")
    List<Map<String, Object>> zwffzjq(YszxQuery dto);

    @ApiOperation("周统计-总警情")
    List<Map<String, Object>> zzjq(YszxQuery dto);

    @ApiOperation("日统计-街面警情")
    List<Map<String, Object>> gfsdfxJmjq(YszxQuery dto);

    @ApiOperation("日统计-违法犯罪警情")
    List<Map<String, Object>> gfsdfxWffzjq(YszxQuery dto);

    @ApiOperation("日统计-总警情")
    List<Map<String, Object>> gfsdfxZjq(YszxQuery dto);

    @ApiOperation("月统计-街面警情")
    List<Map<String, Object>> gfsdfxYjmjq(YszxNyQuery dto);

    @ApiOperation("月统计-违法犯罪警情")
    List<Map<String, Object>> ywffzjq(YszxNyQuery dto);

    @ApiOperation("月统计-总警情")
    List<Map<String, Object>> gfsdfxYzjq(YszxNyQuery dto);

    @ApiOperation("周统计-街面警情")
    List<Map<String, Object>> gfsdfxZjmjq(YszxQuery dto);

    @ApiOperation("周统计-违法犯罪警情")
    List<Map<String, Object>> gfsdfxZwffzjq(YszxQuery dto);

    @ApiOperation("周统计-总警情")
    List<Map<String, Object>> gfsdfxZzjq(YszxQuery dto);

    @ApiOperation("案由类型")
    List<Map<String, Object>> aylx(String code);

    @ApiOperation("组织机构")
    List<Map<String, Object>> zzjg();

    @ApiOperation("警情统计")
    List<Map<String, Object>> zdgzJqtj(YszxQuery dto);

    @ApiOperation("日统计")
    List<Map<String, Object>> rtj(YszxQuery dto);

    @ApiOperation("月统计")
    List<Map<String, Object>> ytj(YszxNyQuery dto);

    @ApiOperation("周统计")
    List<Map<String, Object>> ztj(YszxQuery dto);

    @ApiOperation("日统计-三车人员预警")
    List<Map<String, Object>> scryyj(YszxQuery dto);

    @ApiOperation("月统计-三车人员预警")
    List<Map<String, Object>> yscryyj(YszxQuery dto);

    @ApiOperation("周统计-三车人员预警")
    List<Map<String, Object>> zscryyj(YszxQuery dto);

    @ApiOperation("派出所发案分析--日统计")
    List<Map<String, Object>> pcsfafxRtj(YszxQuery dto);

    @ApiOperation("派出所发案分析--月统计")
    List<Map<String, Object>> pcsfafxytj(YszxNyQuery dto);

    @ApiOperation("派出所发案分析--周统计")
    List<Map<String, Object>> pcsfafxztj(YszxQuery dto);

    @ApiOperation("专题分析-数据统计")
    List<Map<String, Object>> ztsjtj(YszxQuery dto);

    @ApiOperation("专题分析-月数据统计")
    List<Map<String, Object>> yztsjtj(YszxNyQuery dto);

    @ApiOperation("今日警情处置分析")
    List<Map<String, Object>> jrjqczfx(XftjQuery dto);

    @ApiOperation("今日警情数量走势")
    List<Map<String, Object>> jrjqslzs(XftjQuery dto);

    @ApiOperation("今日警情预警")
    List<Map<String, Object>> jrjqyj(XftjQuery dto);

    @ApiOperation("警情类型统计")
    List<Map<String, Object>> jqlxtj(XftjQuery dto);

    @ApiOperation("警情列表")
    IPage<Map<String, Object>> jqlb(XftjJqlbQuery dto);

    @ApiOperation("设备类型统计")
    List<Map<String, Object>> sblxtj(XftjQuery dto);

    @ApiOperation("设备列表")
    IPage<Map<String, Object>> sblb(XftjJqlbQuery dto);

    @ApiOperation("部门列表统计")
    List<Map<String, Object>> jwzbmlbtj(XftjJwzQuery dto);

    @ApiOperation("根据部门统计警务站")
    List<Map<String, Object>> bmtjjwz(XftjJwzQuery dto);

    @ApiOperation("车辆部门统计")
    List<Map<String, Object>> clbmtj(XftjXfllQuery dto);

    @ApiOperation("辅警部门统计")
    List<Map<String, Object>> fjbmtj(XftjXfllQuery dto);

    @ApiOperation("民警部门统计")
    List<Map<String, Object>> mjbmtj(XftjXfllQuery dto);

    @ApiOperation("柱状图统计")
    List<Map<String, Object>> zttjz(XftjXfllQuery dto);

    @ApiOperation("移动装备--部门列表统计")
    List<Map<String, Object>> lbtj(XftjYdzbQuery dto);

    @ApiOperation("移动装备--根据部门统计")
    List<Map<String, Object>> bmtj(XftjYdzbQuery dto);

    @ApiOperation("感知源-部门列表统计")
    List<Map<String, Object>> gzybmlbtj(XftjJqlbQuery dto);
}
